from enum import Enum


class FlawMetaType(str, Enum):
    ERRATA = "ERRATA"
    REFERENCE = "REFERENCE"
    ACKNOWLEDGMENT = "ACKNOWLEDGMENT"
    EXPLOIT = "EXPLOIT"
    MAJOR_INCIDENT = "MAJOR_INCIDENT"
    MAJOR_INCIDENT_LITE = "MAJOR_INCIDENT_LITE"
    REQUIRES_SUMMARY = "REQUIRES_SUMMARY"
    NIST_CVSS_VALIDATION = "NIST_CVSS_VALIDATION"
    NEED_INFO = "NEED_INFO"
    CHECKLIST = "CHECKLIST"
    NVD_CVSS = "NVD_CVSS"

    def __str__(self) -> str:
        return str(self.value)
