from enum import Enum


class ExploitOnlyReportDataSourceEnum(str, Enum):
    CISA = "CISA"
    METASPLOIT = "Metasploit"
    EXPLOIT_DB = "Exploit-DB"

    def __str__(self) -> str:
        return str(self.value)
