from enum import Enum


class OsidbApiV1FlawsListOrderItem(str, Enum):
    VALUE_0 = "-affects__affectedness"
    VALUE_1 = "-affects__created_dt"
    VALUE_2 = "-affects__cvss2"
    VALUE_3 = "-affects__cvss2_score"
    VALUE_4 = "-affects__cvss3"
    VALUE_5 = "-affects__cvss3_score"
    VALUE_6 = "-affects__impact"
    VALUE_7 = "-affects__ps_component"
    VALUE_8 = "-affects__ps_module"
    VALUE_9 = "-affects__resolution"
    VALUE_10 = "-affects__trackers__created_dt"
    VALUE_11 = "-affects__trackers__errata__advisory_name"
    VALUE_12 = "-affects__trackers__external_system_id"
    VALUE_13 = "-affects__trackers__ps_update_stream"
    VALUE_14 = "-affects__trackers__resolution"
    VALUE_15 = "-affects__trackers__status"
    VALUE_16 = "-affects__trackers__type"
    VALUE_17 = "-affects__trackers__updated_dt"
    VALUE_18 = "-affects__trackers__uuid"
    VALUE_19 = "-affects__type"
    VALUE_20 = "-affects__updated_dt"
    VALUE_21 = "-affects__uuid"
    VALUE_22 = "-component"
    VALUE_23 = "-created_dt"
    VALUE_24 = "-cve_id"
    VALUE_25 = "-cvss2"
    VALUE_26 = "-cvss2_score"
    VALUE_27 = "-cvss3"
    VALUE_28 = "-cvss3_score"
    VALUE_29 = "-cwe_id"
    VALUE_30 = "-impact"
    VALUE_31 = "-is_major_incident"
    VALUE_32 = "-nvd_cvss2"
    VALUE_33 = "-nvd_cvss3"
    VALUE_34 = "-reported_dt"
    VALUE_35 = "-source"
    VALUE_36 = "-type"
    VALUE_37 = "-unembargo_dt"
    VALUE_38 = "-updated_dt"
    VALUE_39 = "-uuid"
    AFFECTS_AFFECTEDNESS = "affects__affectedness"
    AFFECTS_CREATED_DT = "affects__created_dt"
    AFFECTS_CVSS2 = "affects__cvss2"
    AFFECTS_CVSS2_SCORE = "affects__cvss2_score"
    AFFECTS_CVSS3 = "affects__cvss3"
    AFFECTS_CVSS3_SCORE = "affects__cvss3_score"
    AFFECTS_IMPACT = "affects__impact"
    AFFECTS_PS_COMPONENT = "affects__ps_component"
    AFFECTS_PS_MODULE = "affects__ps_module"
    AFFECTS_RESOLUTION = "affects__resolution"
    AFFECTS_TRACKERS_CREATED_DT = "affects__trackers__created_dt"
    AFFECTS_TRACKERS_ERRATA_ADVISORY_NAME = "affects__trackers__errata__advisory_name"
    AFFECTS_TRACKERS_EXTERNAL_SYSTEM_ID = "affects__trackers__external_system_id"
    AFFECTS_TRACKERS_PS_UPDATE_STREAM = "affects__trackers__ps_update_stream"
    AFFECTS_TRACKERS_RESOLUTION = "affects__trackers__resolution"
    AFFECTS_TRACKERS_STATUS = "affects__trackers__status"
    AFFECTS_TRACKERS_TYPE = "affects__trackers__type"
    AFFECTS_TRACKERS_UPDATED_DT = "affects__trackers__updated_dt"
    AFFECTS_TRACKERS_UUID = "affects__trackers__uuid"
    AFFECTS_TYPE = "affects__type"
    AFFECTS_UPDATED_DT = "affects__updated_dt"
    AFFECTS_UUID = "affects__uuid"
    COMPONENT = "component"
    CREATED_DT = "created_dt"
    CVE_ID = "cve_id"
    CVSS2 = "cvss2"
    CVSS2_SCORE = "cvss2_score"
    CVSS3 = "cvss3"
    CVSS3_SCORE = "cvss3_score"
    CWE_ID = "cwe_id"
    IMPACT = "impact"
    IS_MAJOR_INCIDENT = "is_major_incident"
    NVD_CVSS2 = "nvd_cvss2"
    NVD_CVSS3 = "nvd_cvss3"
    REPORTED_DT = "reported_dt"
    SOURCE = "source"
    TYPE = "type"
    UNEMBARGO_DT = "unembargo_dt"
    UPDATED_DT = "updated_dt"
    UUID = "uuid"

    def __str__(self) -> str:
        return str(self.value)
