from enum import Enum


class OsidbApiV1SchemaRetrieveLang(str, Enum):
    AF = "af"
    AR = "ar"
    AR_DZ = "ar-dz"
    AST = "ast"
    AZ = "az"
    BE = "be"
    BG = "bg"
    BN = "bn"
    BR = "br"
    BS = "bs"
    CA = "ca"
    CS = "cs"
    CY = "cy"
    DA = "da"
    DE = "de"
    DSB = "dsb"
    EL = "el"
    EN = "en"
    EN_AU = "en-au"
    EN_GB = "en-gb"
    EO = "eo"
    ES = "es"
    ES_AR = "es-ar"
    ES_CO = "es-co"
    ES_MX = "es-mx"
    ES_NI = "es-ni"
    ES_VE = "es-ve"
    ET = "et"
    EU = "eu"
    FA = "fa"
    FI = "fi"
    FR = "fr"
    FY = "fy"
    GA = "ga"
    GD = "gd"
    GL = "gl"
    HE = "he"
    HI = "hi"
    HR = "hr"
    HSB = "hsb"
    HU = "hu"
    HY = "hy"
    IA = "ia"
    ID = "id"
    IG = "ig"
    IO = "io"
    IS = "is"
    IT = "it"
    JA = "ja"
    KA = "ka"
    KAB = "kab"
    KK = "kk"
    KM = "km"
    KN = "kn"
    KO = "ko"
    KY = "ky"
    LB = "lb"
    LT = "lt"
    LV = "lv"
    MK = "mk"
    ML = "ml"
    MN = "mn"
    MR = "mr"
    MY = "my"
    NB = "nb"
    NE = "ne"
    NL = "nl"
    NN = "nn"
    OS = "os"
    PA = "pa"
    PL = "pl"
    PT = "pt"
    PT_BR = "pt-br"
    RO = "ro"
    RU = "ru"
    SK = "sk"
    SL = "sl"
    SQ = "sq"
    SR = "sr"
    SR_LATN = "sr-latn"
    SV = "sv"
    SW = "sw"
    TA = "ta"
    TE = "te"
    TG = "tg"
    TH = "th"
    TK = "tk"
    TR = "tr"
    TT = "tt"
    UDM = "udm"
    UK = "uk"
    UR = "ur"
    UZ = "uz"
    VI = "vi"
    ZH_HANS = "zh-hans"
    ZH_HANT = "zh-hant"

    def __str__(self) -> str:
        return str(self.value)
